@@ -87,14 +87,13 @@ class AtlassianRestAPI(object):
         """
         self._session.headers.update({key: value})
 
-    def log_curl_debug(self, method, path, data=None, headers=None, trailing=None, level=logging.DEBUG):
+    def log_curl_debug(self, method, url, data=None, headers=None, level=logging.DEBUG):
         """
 
         :param method:
-        :param path:
+        :param url:
         :param data:
         :param headers:
-        :param trailing: bool flag for trailing /
         :param level:
         :return:
         """
@@ -103,7 +102,7 @@ class AtlassianRestAPI(object):
             method=method,
             headers=' -H '.join(["'{0}: {1}'".format(key, value) for key, value in headers.items()]),
             data='' if not data else "--data '{0}'".format(json.dumps(data)),
-            url='{0}'.format(self.url_joiner(self.url, path=path, trailing=trailing)))
+            url=url)
         log.log(level=level, msg=message)
 
     def resource_url(self, resource):
@@ -130,7 +129,6 @@ class AtlassianRestAPI(object):
         :param trailing: bool
         :return:
         """
-        self.log_curl_debug(method=method, path=path, headers=headers, data=data, trailing=None)
         url = self.url_joiner(self.url, path, trailing)
         if params or flags:
             url += '?'
@@ -140,6 +138,8 @@ class AtlassianRestAPI(object):
             url += ('&' if params else '') + '&'.join(flags or [])
         if files is None:
             data = None if not data else json.dumps(data)
+        self.log_curl_debug(method=method, url=url, headers=headers,
+                            data=data)
 
         headers = headers or self.default_headers
         response = self._session.request(
@@ -153,45 +153,12 @@ class AtlassianRestAPI(object):
             proxies=self.proxies
         )
         response.encoding = 'utf-8'
+
         if self.advanced_mode:
-            self.response = response
             return response
-        try:
-            if response.text:
-                response_content = response.json()
-            else:
-                response_content = response.content
-        except ValueError:
-            response_content = response.content
-        if response.status_code == 200:
-            log.debug('Received: {0}\n {1}'.format(response.status_code, response_content))
-        elif response.status_code == 201:
-            log.debug('Received: {0}\n "Created" response'.format(response.status_code))
-        elif response.status_code == 204:
-            log.debug('Received: {0}\n "No Content" response'.format(response.status_code))
-        elif response.status_code == 400:
-            log.error('Received: {0}\n Bad request \n {1}'.format(response.status_code, response_content))
-        elif response.status_code == 401:
-            log.error('Received: {0}\n "UNAUTHORIZED" response'.format(response.status_code))
-        elif response.status_code == 404:
-            log.error('Received: {0}\n Not Found'.format(response.status_code))
-        elif response.status_code == 403:
-            log.error('Received: {0}\n Forbidden. Please, check permissions'.format(response.status_code))
-        elif response.status_code == 405:
-            log.error('Received: {0}\n Method not allowed'.format(response.status_code))
-        elif response.status_code == 409:
-            log.error('Received: {0}\n Conflict \n {1}'.format(response.status_code, response_content))
-        elif response.status_code == 413:
-            log.error('Received: {0}\n Request entity too large'.format(response.status_code))
-        else:
-            log.debug('Received: {0}\n {1}'.format(response.status_code, response))
-            self.log_curl_debug(method=method, path=path, headers=headers, data=data, level=logging.DEBUG)
-            log.error(response_content)
-            try:
-                response.raise_for_status()
-            except requests.exceptions.HTTPError as err:
-                log.error("HTTP Error occurred")
-                log.error('Response is: {content}'.format(content=err.response.content))
+
+        log.debug("HTTP: {} {} -> {} {}".format(method, path, response.status_code, response.reason))
+        response.raise_for_status()
         return response
 
     def get(self, path, data=None, flags=None, params=None, headers=None, not_json_response=None, trailing=None):
